@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: path-pieces
 version: 0.2.1
-id: path-pieces-0.2.1-1993cf7409b1066d7297872970b0fe71
-key: pathp_8Iy5estukyS3zLkvi3notZ
+id: path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
+key: pathp_Idrdy6ATKgw33OZB8mjFUB
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: unstable
@@ -19,10 +19,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/path-pieces-0.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/path-pieces-0.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/path-pieces-0.2.1
-hs-libraries: HSpath-pieces-0.2.1-8Iy5estukyS3zLkvi3notZ
+hs-libraries: HSpath-pieces-0.2.1-Idrdy6ATKgw33OZB8mjFUB
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
 haddock-interfaces: /usr/share/doc/haskell-path-pieces/html/path-pieces.haddock
 haddock-html: /usr/share/doc/haskell-path-pieces/html
